==> huaweicloudsdkeip-3.1.108-py2.py3-none-any.whl: huaweicloudsdkeip/v3/model/nexthop_dict.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NexthopDict:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ip_address': 'str',
        'mode': 'str'
    }

    attribute_map = {
        'ip_address': 'ip_address',
        'mode': 'mode'
    }

    def __init__(self, ip_address=None, mode=None):
        """NexthopDict

        The model defined in huaweicloud sdk

        :param ip_address: 功能说明：下一跳的实际地址  约束：同一virtualnexthop中的nexthops列表，不同下一跳之间的地址不允许重复
        :type ip_address: str
        :param mode: 功能说明：标识主备模式，与virtualnexthop的forward_mode配合使用  取值范围：&#39;ACTIVE&#39;主、&#39;STANDBY&#39;备
        :type mode: str
        """
        
        

        self._ip_address = None
        self._mode = None
        self.discriminator = None

        if ip_address is not None:
            self.ip_address = ip_address
        if mode is not None:
            self.mode = mode

    @property
    def ip_address(self):
        """Gets the ip_address of this NexthopDict.

        功能说明：下一跳的实际地址  约束：同一virtualnexthop中的nexthops列表，不同下一跳之间的地址不允许重复

        :return: The ip_address of this NexthopDict.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this NexthopDict.

        功能说明：下一跳的实际地址  约束：同一virtualnexthop中的nexthops列表，不同下一跳之间的地址不允许重复

        :param ip_address: The ip_address of this NexthopDict.
        :type ip_address: str
        """
        self._ip_address = ip_address

    @property
    def mode(self):
        """Gets the mode of this NexthopDict.

        功能说明：标识主备模式，与virtualnexthop的forward_mode配合使用  取值范围：'ACTIVE'主、'STANDBY'备

        :return: The mode of this NexthopDict.
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this NexthopDict.

        功能说明：标识主备模式，与virtualnexthop的forward_mode配合使用  取值范围：'ACTIVE'主、'STANDBY'备

        :param mode: The mode of this NexthopDict.
        :type mode: str
        """
        self._mode = mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NexthopDict):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeip-3.1.145-py2.py3-none-any.whl: huaweicloudsdkeip/v3/model/nexthop_dict.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NexthopDict:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ip_address': 'str',
        'mode': 'str'
    }

    attribute_map = {
        'ip_address': 'ip_address',
        'mode': 'mode'
    }

    def __init__(self, ip_address=None, mode=None):
        r"""NexthopDict

        The model defined in huaweicloud sdk

        :param ip_address: 功能说明：下一跳的实际地址  约束：同一virtualnexthop中的nexthops列表，不同下一跳之间的地址不允许重复
        :type ip_address: str
        :param mode: 功能说明：标识主备模式，与virtualnexthop的forward_mode配合使用  取值范围：&#39;ACTIVE&#39;主、&#39;STANDBY&#39;备
        :type mode: str
        """
        
        

        self._ip_address = None
        self._mode = None
        self.discriminator = None

        if ip_address is not None:
            self.ip_address = ip_address
        if mode is not None:
            self.mode = mode

    @property
    def ip_address(self):
        r"""Gets the ip_address of this NexthopDict.

        功能说明：下一跳的实际地址  约束：同一virtualnexthop中的nexthops列表，不同下一跳之间的地址不允许重复

        :return: The ip_address of this NexthopDict.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        r"""Sets the ip_address of this NexthopDict.

        功能说明：下一跳的实际地址  约束：同一virtualnexthop中的nexthops列表，不同下一跳之间的地址不允许重复

        :param ip_address: The ip_address of this NexthopDict.
        :type ip_address: str
        """
        self._ip_address = ip_address

    @property
    def mode(self):
        r"""Gets the mode of this NexthopDict.

        功能说明：标识主备模式，与virtualnexthop的forward_mode配合使用  取值范围：'ACTIVE'主、'STANDBY'备

        :return: The mode of this NexthopDict.
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        r"""Sets the mode of this NexthopDict.

        功能说明：标识主备模式，与virtualnexthop的forward_mode配合使用  取值范围：'ACTIVE'主、'STANDBY'备

        :param mode: The mode of this NexthopDict.
        :type mode: str
        """
        self._mode = mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NexthopDict):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
